==> gemrb-0.3.0.tar.gz: gemrb-0.3.0/gemrb/plugins/Core/ResourceMgr.h <==
/* GemRB - Infinity Engine Emulator
 * Copyright (C) 2003 The GemRB Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: ResourceMgr.h 4503 2007-02-27 16:43:46Z wjpalenstijn $
 *
 */

#ifndef RESOURCEMGR_H
#define RESOURCEMGR_H

#include "Plugin.h"
#include "../../includes/SClassID.h"
#include "DataStream.h"
#include "../../includes/globals.h"

#ifdef WIN32

#ifdef GEM_BUILD_DLL
#define GEM_EXPORT __declspec(dllexport)
#else
#define GEM_EXPORT __declspec(dllimport)
#endif

#else
#define GEM_EXPORT
#endif

class GEM_EXPORT ResourceMgr : public Plugin {
public:
	ResourceMgr(void);
	virtual ~ResourceMgr(void);
	virtual bool LoadResFile(const char* resfile) = 0;
	virtual bool HasResource(const char* resname, SClass_ID type) = 0;
	virtual DataStream* GetResource(const char* resname, SClass_ID type) = 0;
	virtual void* GetFactoryResource(const char* resname, SClass_ID type,
		unsigned char mode = IE_NORMAL) = 0;
};

#endif

==> gemrb-0.3.1.tar.gz: gemrb-0.3.1/gemrb/plugins/Core/ResourceMgr.h <==
/* GemRB - Infinity Engine Emulator
 * Copyright (C) 2003 The GemRB Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: ResourceMgr.h 5197 2008-06-10 16:27:43Z avenger_teambg $
 *
 */

#ifndef RESOURCEMGR_H
#define RESOURCEMGR_H

#include "Plugin.h"
#include "../../includes/SClassID.h"
#include "DataStream.h"
#include "../../includes/globals.h"

#ifdef WIN32

#ifdef GEM_BUILD_DLL
#define GEM_EXPORT __declspec(dllexport)
#else
#define GEM_EXPORT __declspec(dllimport)
#endif

#else
#define GEM_EXPORT
#endif

class GEM_EXPORT ResourceMgr : public Plugin {
public:
	ResourceMgr(void);
	virtual ~ResourceMgr(void);
	virtual bool LoadResFile(const char* resfile) = 0;
	virtual bool HasResource(const char* resname, SClass_ID type, bool silent=false) = 0;
	virtual DataStream* GetResource(const char* resname, SClass_ID type) = 0;
	virtual void* GetFactoryResource(const char* resname, SClass_ID type,
		unsigned char mode = IE_NORMAL) = 0;
};

#endif
